@@ -9,6 +9,8 @@ from vatis.asr_commons.domain.transcriber import SpacedLogitsDataPacket
 
 from vatis.asr_commons.domain.exception import AudioFormatError
 
+from vatis.asr_commons.domain.speaker import SpeakerDiarization
+
 __all__ = (
     'DataPacket',
     'ByteDataPacket',
@@ -18,5 +20,6 @@ __all__ = (
     'NdArrayDataPacket',
     'LogitsDataPacket',
     'SpacedLogitsDataPacket',
-    'AudioFormatError'
+    'AudioFormatError',
+    'SpeakerDiarization'
 )
